@@ -1,4 +1,4 @@
-# -*- coding: utf8 -*- 
+# -*- coding: utf-8 -*- 
 
 from django.conf import settings
 from django.contrib.auth.models import User
@@ -27,7 +27,7 @@ class Post(models.Model):
     user = models.ForeignKey(User)
     like = models.IntegerField(default=0)
     url = models.CharField(blank=True, max_length=2000, validators=[URLValidator()])
-    category = models.ForeignKey(Category)
+    category = models.ForeignKey(Category, null=True, blank=True, default=0)
     
     tags = TaggableManager(blank=True)
     
@@ -141,4 +141,4 @@ post_save.connect(Stream.add_post, sender=Post)
 post_save.connect(Likes.user_like_post, sender=Likes)
 post_delete.connect(Likes.user_unlike_post, sender=Likes)
 post_save.connect(Post.change_tag_slug, sender=Tag)
-comment_was_posted.connect(user_comment_post, sender=Comment)
\ No newline at end of file
+comment_was_posted.connect(user_comment_post, sender=Comment)
