@@ -188,14 +188,20 @@ def sendurl(request):
             model = form.save(commit=False)
             
             category = post_values['category']
-                
+            
             if category.startswith('newcat-'):
                 category = category.replace('newcat-', '')
                 category, created = Category.objects.get_or_create(user=request.user,name=category)
+                category_id = category.id
+
+            elif int(category) == 0:
+                #category, created = Category.objects.get_or_create(user=request.user, name=u'ﺏﺩﻮﻧ ﺪﺴﺘﻫ ﺐﻧﺩی')
+                category_id = None
             else:
-                category = Category.objects.filter(user=request.user, id=category).all()
+                category = Category.objects.filter(user=request.user, id=category).all()[0]
+                category_id = category.id
                 
-            model.category_id = category.id
+            model.category_id = category_id
             
             image_url= model.image
             
@@ -253,14 +259,19 @@ def send(request):
             model = form.save(commit=False)
             
             category = post_values['category']
-                
+             
             if category.startswith('newcat-'):
                 category = category.replace('newcat-', '')
                 category, created = Category.objects.get_or_create(user=request.user,name=category)
+                category_id = category.id
+            elif  int(category) == 0:
+                #category, created = Category.objects.get_or_create(user=request.user, name=u'بدون دسته بندی')
+                category_id = None
             else:
                 category = Category.objects.filter(user=request.user, id=category).all()
+                category_id = category.id
                 
-            model.category_id = category.id
+            model.category_id = category_id
             
             filename= model.image
             
@@ -310,13 +321,19 @@ def edit(request, post_id):
                 model = form.save(commit=False)
                 category = post_values['category']
                 
+
                 if category.startswith('newcat-'):
                     category = category.replace('newcat-', '')
                     category, created = Category.objects.get_or_create(user=request.user,name=category)
+                    category_id = category.id
+                elif int(category) == 0:
+                    #category, created = Category.objects.get_or_create(user=request.user, name=u'ﺏﺩﻮﻧ ﺪﺴﺘﻫ ﺐﻧﺩی')
+                    category_id = None
                 else:
-                    category = Category.objects.filter(user=request.user, id=category).all()
+                    category = Category.objects.filter(user=request.user, id=category).all()[0]
+                    category_id = category.id
                     
-                model.category_id = category.id
+                model.category_id = category_id
                 
                 model.save()
                 
